.. _lofardemolobes:

LOFAR telescope: assessing the LOBEs model
==========================================

This demo illustrates how the EveryBeam python bindings can be used to generate all-sky
images of the beam response (full response or element response) for a LOFAR observation, where
the LOBEs model is used as the underlying element response model.

.. literalinclude:: ../../../demo/python/lobesimage.py